downloadModel method

Future<bool?> downloadModel(
  1. String modelUrl,
  2. String destinationPath, {
  3. String? language,
})

Downloads a model for offline speech recognition (Android only).

modelUrl is the URL to download the model from. destinationPath is the absolute path where the model should be saved. language is the language code for the model.

Returns true if the download was successful, false otherwise.

Implementation

Future<bool?> downloadModel(String modelUrl, String destinationPath, {String? language}) {
  throw UnimplementedError('downloadModel() has not been implemented.');
}